WARNING - OLD ARCHIVES

This is an archived copy of the Xen.org mailing list, which we have preserved to ensure that existing links to archives are not broken. The live archive, which contains the latest emails, can be found at http://lists.xen.org/
   
 
 
Xen 
 
Home Products Support Community News
 
   
 

xen-changelog

[Xen-changelog] Remove update_vcpu_system_time() call from the per-VCPU

To: xen-changelog@xxxxxxxxxxxxxxxxxxx
Subject: [Xen-changelog] Remove update_vcpu_system_time() call from the per-VCPU timer
From: Xen patchbot -3.0-testing <patchbot-3.0-testing@xxxxxxxxxxxxxxxxxxx>
Date: Sat, 22 Apr 2006 14:48:18 +0000
Delivery-date: Sat, 22 Apr 2006 07:58:06 -0700
Envelope-to: www-data@xxxxxxxxxxxxxxxxxx
List-help: <mailto:xen-changelog-request@lists.xensource.com?subject=help>
List-id: BK change log <xen-changelog.lists.xensource.com>
List-post: <mailto:xen-changelog@lists.xensource.com>
List-subscribe: <http://lists.xensource.com/cgi-bin/mailman/listinfo/xen-changelog>, <mailto:xen-changelog-request@lists.xensource.com?subject=subscribe>
List-unsubscribe: <http://lists.xensource.com/cgi-bin/mailman/listinfo/xen-changelog>, <mailto:xen-changelog-request@lists.xensource.com?subject=unsubscribe>
Reply-to: xen-devel@xxxxxxxxxxxxxxxxxxx
Sender: xen-changelog-bounces@xxxxxxxxxxxxxxxxxxx
# HG changeset patch
# User kaf24@xxxxxxxxxxxxxxxxxxxx
# Node ID 8821da562fe0199a92f165b444e08fd63ef60296
# Parent  93f0f91631240e6c8d188cd2d8876cdebb910a68
Remove update_vcpu_system_time() call from the per-VCPU timer
callback function. It's unnecessary and in fact may occasionally
even run on the wrong CPU.

Signed-off-by: Keir Fraser <keir@xxxxxxxxxxxxx>

diff -r 93f0f9163124 -r 8821da562fe0 xen/common/schedule.c
--- a/xen/common/schedule.c     Fri Apr 21 18:10:13 2006 +0100
+++ b/xen/common/schedule.c     Sat Apr 22 10:29:27 2006 +0100
@@ -42,7 +42,7 @@ string_param("sched", opt_sched);
 /* Various timer handlers. */
 static void s_timer_fn(void *unused);
 static void t_timer_fn(void *unused);
-static void dom_timer_fn(void *data);
+static void vcpu_timer_fn(void *data);
 static void poll_timer_fn(void *data);
 
 /* This is global for now so that private implementations can reach it */
@@ -167,7 +167,7 @@ void sched_add_domain(struct vcpu *v)
 void sched_add_domain(struct vcpu *v) 
 {
     /* Initialise the per-domain timers. */
-    init_timer(&v->timer, dom_timer_fn, v, v->processor);
+    init_timer(&v->timer, vcpu_timer_fn, v, v->processor);
     init_timer(&v->poll_timer, poll_timer_fn, v, v->processor);
 
     if ( is_idle_vcpu(v) )
@@ -618,12 +618,10 @@ static void t_timer_fn(void *unused)
     set_timer(&t_timer[cpu], NOW() + MILLISECS(10));
 }
 
-/* Domain timer function, sends a virtual timer interrupt to domain */
-static void dom_timer_fn(void *data)
+/* Per-VCPU timer function: sends a virtual timer interrupt. */
+static void vcpu_timer_fn(void *data)
 {
     struct vcpu *v = data;
-
-    update_dom_time(v);
     send_timer_event(v);
 }
 

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog

<Prev in Thread] Current Thread [Next in Thread>